@@ -169,6 +169,8 @@ def _hand_convert(name, oldpars, version=(3, 1, 2)):
         oldpars = _hand_convert_3_1_2_to_4_1(name, oldpars)
     if version < (4, 2, 0):
         oldpars = _rename_magnetic_pars(oldpars)
+    if version <= (5, 0, 4):
+        oldpars = _rename_magnetic_angles(oldpars)    
     return oldpars
 
 def _rename_magnetic_pars(pars):
@@ -187,6 +189,17 @@ def _rename_magnetic_pars(pars):
             pars['up_'+k[3:]] = pars.pop(k)
     return pars
 
+
+def _rename_magnetic_angles(pars):
+    """
+    Change name of magnetic angle.
+    """
+    if 'up_angle' in pars:      
+        pars['up_theta'] = 90
+        pars['up_phi'] = pars['up_angle']
+        pars.pop('up_angle') 
+    return pars    
+
 def _hand_convert_3_1_2_to_4_1(name, oldpars):
     if name == 'core_shell_parallelepiped':
         # Make sure pd on rim parameters defaults to zero
@@ -354,6 +367,7 @@ def convert_model(name, pars, use_underscore=False, model_version=(3, 1, 2)):
             newpars = _rescale_sld(model_info, newpars, 1e6)
         newpars.setdefault('scale', 1.0)
         newpars.setdefault('background', 0.0)
+        newpars.setdefault('up_theta', 90.0)
         if use_underscore:
             newpars = _pd_to_underscores(newpars)
         name = newname
