@@ -187,8 +187,54 @@
 #endif
 inline double square(double x) { return x*x; }
 inline double cube(double x) { return x*x*x; }
+// clip() follows numpy.clip() semantics, returning (x < low ? low : x > high ? high : x)
+// OpenCL/CUDA clamp() returns fmin(fmax(x, low), high)
+// C++(17) clamp() matches numpy.clip()
+// If x is NaN numpy.clip() returns NaN but OpenCL clamp() returns low.
+inline double clip(double x, double low, double high) { return x < low ? low : x > high ? high : x; }
 inline double sas_sinx_x(double x) { return x==0 ? 1.0 : sin(x)/x; }
 
+// vector algebra
+static void SET_VEC(double *vector, double v0, double v1, double v2)
+{
+    vector[0] = v0;
+    vector[1] = v1;
+    vector[2] = v2;
+}
+
+static void SCALE_VEC(double *vector, double a)
+{
+    vector[0] = a*vector[0];
+    vector[1] = a*vector[1];
+    vector[2] = a*vector[2];
+}
+
+static void ADD_VEC(double *result_vec, double *vec1, double *vec2)
+{
+    result_vec[0] = vec1[0] + vec2[0];
+    result_vec[1] = vec1[1] + vec2[1];
+    result_vec[2] = vec1[2] + vec2[2];
+}
+
+static double SCALAR_VEC( double *vec1, double *vec2)
+{
+    return vec1[0] * vec2[0] + vec1[1] * vec2[1] + vec1[2] * vec2[2];
+}
+
+static double MAG_VEC( double *vec)
+{
+    return sqrt(SCALAR_VEC(vec,vec));
+}
+
+
+static void ORTH_VEC(double *result_vec, double *vec1, double *vec2)
+{
+    double scale =  SCALAR_VEC(vec1,vec2) / SCALAR_VEC(vec2,vec2);
+    result_vec[0] = vec1[0] - scale * vec2[0];
+    result_vec[1] = vec1[1] - scale * vec2[1];
+    result_vec[2] = vec1[2] - scale * vec2[2];
+}
+
 // CRUFT: support old style models with orientation received qx, qy and angles
 
 // To rotate from the canonical position to theta, phi, psi, first rotate by
