@@ -8,7 +8,7 @@ Usage::
 
 If model1 is 'all', then all except the remaining models will be tested.
 Subgroups are also possible, such as 'py', 'single' or '1d'.  See
-:func:`core.list_models` for details.
+:func:`.core.list_models` for details.
 
 Each model is tested using the default parameters at q=0.1, (qx, qy)=(0.1, 0.1),
 and Fq is called to make sure R_eff, volume and volume ratio are computed.
@@ -70,12 +70,12 @@ from . import product
 
 # pylint: disable=unused-import
 try:
-    from typing import List, Iterator, Callable
-except ImportError:
-    pass
-else:
+    from typing import List, Iterator, Callable, Any, Dict, Tuple, Union
     from .modelinfo import ParameterTable, ParameterSet, TestCondition, ModelInfo
     from .kernel import KernelModel
+    DType = Union[None, str, np.dtype]
+except ImportError:
+    pass
 # pylint: enable=unused-import
 
 def make_suite(loaders, models):
@@ -132,7 +132,7 @@ def _add_model_to_suite(loaders, suite, model_info):
     stash = []
 
     if is_py:  # kernel implemented in python
-        test_name = "%s-python"%model_info.name
+        test_name = "%s[python]"%model_info.name
         test_method_name = "test_%s_python" % model_info.id
         test = ModelTestCase(test_name, model_info,
                              test_method_name,
@@ -144,7 +144,7 @@ def _add_model_to_suite(loaders, suite, model_info):
 
         # test using dll if desired
         if 'dll' in loaders or not use_opencl():
-            test_name = "%s-dll"%model_info.name
+            test_name = "%s[dll]"%model_info.name
             test_method_name = "test_%s_dll" % model_info.id
             test = ModelTestCase(test_name, model_info,
                                  test_method_name,
@@ -155,7 +155,7 @@ def _add_model_to_suite(loaders, suite, model_info):
 
         # test using opencl if desired and available
         if 'opencl' in loaders and use_opencl():
-            test_name = "%s-opencl"%model_info.name
+            test_name = "%s[opencl]"%model_info.name
             test_method_name = "test_%s_opencl" % model_info.id
             # Using dtype=None so that the models that are only
             # correct for double precision are not tested using
@@ -170,7 +170,7 @@ def _add_model_to_suite(loaders, suite, model_info):
 
         # test using cuda if desired and available
         if 'cuda' in loaders and use_cuda():
-            test_name = "%s-cuda" % model_info.id
+            test_name = "%s[cuda]" % model_info.id
             test_method_name = "test_%s_cuda" % model_info.id
             # Using dtype=None so that the models that are only
             # correct for double precision are not tested using
@@ -354,6 +354,7 @@ def _hide_model_case_from_nose():
             else:
                 self._failures.append('wrong number or results for %s => %s'
                                       % (str(user_pars), str(test[2:])))
+                return None
 
         def _check_scalar(self, target, actual, name):
             if not is_near(target, actual, 5):
@@ -417,7 +418,7 @@ def _hide_model_case_from_nose():
     return ModelTestCase
 
 def invalid_pars(partable, pars):
-    # type: (ParameterTable, Dict[str, float])
+    # type: (ParameterTable, Dict[str, float]) -> List[str]
     """
     Return a list of parameter names that are not part of the model.
     """
@@ -580,7 +581,7 @@ def model_tests():
 
 
 def main():
-    # type: (*str) -> int
+    # type: () -> int
     """
     Run tests given is models.
 
