@@ -24,21 +24,22 @@ double Iq(double q, double fp_case_num,
   double Paa,S0aa,Pab,S0ab,Pac,S0ac,Pad,S0ad;
   double S0ba,Pbb,S0bb,Pbc,S0bc,Pbd,S0bd;
   double S0ca,S0cb,Pcc,S0cc,Pcd,S0cd;
-  double S0da,S0db,S0dc;
+  //double S0da,S0db,S0dc;
   double Pdd,S0dd;
   double Kaa,Kbb,Kcc;
   double Kba,Kca,Kcb;
-  double Kda,Kdb,Kdc,Kdd;
+  //double Kda,Kdb,Kdc,Kdd;
   double Zaa,Zab,Zac,Zba,Zbb,Zbc,Zca,Zcb,Zcc;
   double DenT,T11,T12,T13,T21,T22,T23,T31,T32,T33;
   double Y1,Y2,Y3,X11,X12,X13,X21,X22,X23,X31,X32,X33;
   double ZZ,DenQ1,DenQ2,DenQ3,DenQ,Q11,Q12,Q13,Q21,Q22,Q23,Q31,Q32,Q33;
   double N11,N12,N13,N21,N22,N23,N31,N32,N33;
   double M11,M12,M13,M21,M22,M23,M31,M32,M33;
-  double S11,S12,S13,S14,S21,S22,S23,S24;
-  double S31,S32,S33,S34,S41,S42,S43,S44;
+  double S11,S12,S22,S23,S13,S33;
+  //double S21,S31,S32,S44; 
+  //double S14,S24,S34,S41,S42,S43;
   double Lad,Lbd,Lcd,Nav,Intg;
-  
+
   // Set values for non existent parameters (eg. no A or B in case 0 and 1 etc)
   //icase was shifted to N-1 from the original code
   if (icase <= 1){
@@ -57,7 +58,7 @@ double Iq(double q, double fp_case_num,
     b[0] = 5.0;
     Kab = Kac = Kad = -0.0004;
   }
- 
+
   // Set volume fraction of component D based on constraint that sum of vol frac =1
   Phi[3]=1.0-Phi[0]-Phi[1]-Phi[2];
 
@@ -83,7 +84,7 @@ double Iq(double q, double fp_case_num,
   Phibd=sqrt(Phi[1]*Phi[3]);
   Phicd=sqrt(Phi[2]*Phi[3]);
 
-  // Calculate Q^2 * Rg^2 for each homopolymer assuming random walk 
+  // Calculate Q^2 * Rg^2 for each homopolymer assuming random walk
   Xa=q*q*b[0]*b[0]*N[0]/6.0;
   Xb=q*q*b[1]*b[1]*N[1]/6.0;
   Xc=q*q*b[2]*b[2]*N[2]/6.0;
@@ -114,9 +115,9 @@ double Iq(double q, double fp_case_num,
   Pcd=((1.0-exp(-Xc))/Xc)*((1.0-exp(-Xd))/Xd); // CD diblock
   S0cd=(Phicd*vcd*Ncd)*Pcd;
 
-  S0da=S0ad;
-  S0db=S0bd;
-  S0dc=S0cd;
+  //S0da=S0ad;
+  //S0db=S0bd;
+  //S0dc=S0cd;
   Pdd=2.0*(exp(-Xd)-1.0+Xd)/(Xd*Xd); // free D chain
   S0dd=N[3]*Phi[3]*v[3]*Pdd;
 
@@ -197,22 +198,22 @@ double Iq(double q, double fp_case_num,
   S0ba=S0ab;
   S0ca=S0ac;
   S0cb=S0bc;
-  S0da=S0ad;
-  S0db=S0bd;
-  S0dc=S0cd;
+  //S0da=S0ad;
+  //S0db=S0bd;
+  //S0dc=S0cd;
 
   // self chi parameter is 0 ... of course
   Kaa=0.0;
   Kbb=0.0;
   Kcc=0.0;
-  Kdd=0.0;
+  //Kdd=0.0;
 
   Kba=Kab;
   Kca=Kac;
   Kcb=Kbc;
-  Kda=Kad;
-  Kdb=Kbd;
-  Kdc=Kcd;
+  //Kda=Kad;
+  //Kdb=Kbd;
+  //Kdc=Kcd;
 
   Zaa=Kaa-Kad-Kad;
   Zab=Kab-Kad-Kbd;
@@ -293,24 +294,24 @@ double Iq(double q, double fp_case_num,
   S11= Q11*S0aa + Q21*S0ab + Q31*S0ac;
   S12= Q12*S0aa + Q22*S0ab + Q32*S0ac;
   S13= Q13*S0aa + Q23*S0ab + Q33*S0ac;
-  S14=-S11-S12-S13;
-  S21= Q11*S0ba + Q21*S0bb + Q31*S0bc;
   S22= Q12*S0ba + Q22*S0bb + Q32*S0bc;
   S23= Q13*S0ba + Q23*S0bb + Q33*S0bc;
-  S24=-S21-S22-S23;
-  S31= Q11*S0ca + Q21*S0cb + Q31*S0cc;
-  S32= Q12*S0ca + Q22*S0cb + Q32*S0cc;
   S33= Q13*S0ca + Q23*S0cb + Q33*S0cc;
-  S34=-S31-S32-S33;
-  S41=S14;
-  S42=S24;
-  S43=S34;
-  S44=S11+S22+S33+2.0*S12+2.0*S13+2.0*S23;
+  //S21= Q11*S0ba + Q21*S0bb + Q31*S0bc;
+  //S31= Q11*S0ca + Q21*S0cb + Q31*S0cc;
+  //S32= Q12*S0ca + Q22*S0cb + Q32*S0cc;
+  //S44=S11+S22+S33+2.0*S12+2.0*S13+2.0*S23;
+  //S14=-S11-S12-S13;
+  //S24=-S21-S22-S23;
+  //S34=-S31-S32-S33;
+  //S41=S14;
+  //S42=S24;
+  //S43=S34;
 
   //calculate contrast where L[i] is the scattering length of i and D is the matrix
   //Note that should multiply by Nav to get units of SLD which will become
   // Nav*2 in the next line (SLD^2) but then normalization in that line would
-  //need to divide by Nav leaving only Nav or sqrt(Nav) before squaring. 
+  //need to divide by Nav leaving only Nav or sqrt(Nav) before squaring.
   Nav=6.022045e+23;
   Lad=(L[0]/v[0]-L[3]/v[3])*sqrt(Nav);
   Lbd=(L[1]/v[1]-L[3]/v[3])*sqrt(Nav);
@@ -319,7 +320,7 @@ double Iq(double q, double fp_case_num,
   Intg=Lad*Lad*S11+Lbd*Lbd*S22+Lcd*Lcd*S33+2.0*Lad*Lbd*S12+2.0*Lbd*Lcd*S23+2.0*Lad*Lcd*S13;
 
   //rescale for units of Lij^2 (fm^2 to cm^2)
-  Intg *= 1.0e-26;    
+  Intg *= 1.0e-26;
 
   return Intg;
 
