@@ -16,7 +16,8 @@ The scattering intensity $I(q)$ is calculated as
     F(x) &= \frac{3\left[\sin(x)-x\cos(x)\right]}{x^3} \\
     S(q) &= \Gamma(5-D_S)\xi^{\,5-D_S}\left[1+(q\xi)^2 \right]^{-(5-D_S)/2}
             \sin\left[-(5-D_S) \tan^{-1}(q\xi) \right] q^{-1} \\
-    \text{scale} &= \text{scale factor}\, N V^1(\rho_\text{particle} - \rho_\text{solvent})^2 \\
+    \text{scale} &= \text{scale factor}\,
+        N V^1(\rho_\text{particle} - \rho_\text{solvent})^2 \\
     V &= \frac{4}{3}\pi R^3
     \end{align*}
 
@@ -27,8 +28,8 @@ length density of particles.
 
 .. note::
 
-    The surface fractal dimension is only valid if $1<D_S<3$. The result is
-    only valid over a limited $q$ range, $\tfrac{5}{3-D_S}\xi^{\,-1} < q < R^{-1}$.
+    The surface fractal dimension is only valid if $1<D_S<3$. The result is only
+    valid over a limited $q$ range, $\tfrac{5}{3-D_S}\xi^{\,-1} < q < R^{-1}$.
     See the reference for details.
 
 
